# Baleen as a Service

The next upgrades for Baleen are a background daemonization and scheduled ingestion cycle as well as a fancy web application for making sure everything works smoothly. It is our hope that Baleen in this context will do far better at ingestion than one off collects by a human being. Our back-of-the-napkin architecture is as follows:

[![Baleen Service Architecture](/images/service_architecture.png)](/images/service_architecture.png)

Requirements and features will grow in the future; and hopefully be less napkin-y. But that's it for now!
